import React from 'react';
import { useEffect } from 'react';
import { Shield } from 'lucide-react';
import Footer from '../components/Footer';

const PrivacyPolicy = () => {
  useEffect(() => {
    document.title = 'Privacy Policy | Sales Assist AI';
    // Update meta description
    const metaDescription = document.querySelector('meta[name="description"]');
    if (metaDescription) {
      metaDescription.setAttribute('content', 'Our privacy policy explains how we collect, use, and protect your personal information when you use our AI-powered communication platform.');
    }
    // Scroll to top when component mounts
    window.scrollTo({ top: 0, behavior: 'smooth' });
  }, []);

  return (
    <div className="min-h-screen bg-white">
      <div className="container max-w-4xl mx-auto pt-32 pb-16 px-4">
        <div className="text-center mb-12">
          <div className="inline-flex items-center gap-2 px-4 py-2 rounded-full bg-primary-50 border border-primary-100 mb-4">
            <div className="p-1 bg-gradient-to-r from-primary-500 to-primary-600 rounded-full">
              <Shield className="w-4 h-4 text-white" />
            </div>
            <span className="text-sm font-medium text-primary-700">
              PRIVACY POLICY
            </span>
          </div>
          
          <h1 className="text-4xl font-bold text-secondary-900 mb-4">
            Privacy Policy
            <span className="block text-gradient mt-2">Your Data, Protected</span>
          </h1>
          <p className="text-xl text-secondary-600">
            Last updated: January 26, 2025
          </p>
        </div>

        <div className="prose prose-lg max-w-none">
          <div className="bg-white rounded-3xl border border-primary-100/50 shadow-soft p-8 space-y-8">
            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">1. Introduction</h2>
              <p>
                Sales Assist AI ("we," "our," or "us") is committed to protecting your privacy. This Privacy Policy explains how we collect, use, disclose, and safeguard your information when you use our AI-powered communication platform and related services.
              </p>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">2. Information We Collect</h2>
              <h3 className="text-xl font-medium text-secondary-900 mb-2">2.1 Information You Provide</h3>
              <ul className="list-disc pl-6 mb-4">
                <li>Name and contact information</li>
                <li>Email address</li>
                <li>Phone number</li>
                <li>Company information</li>
                <li>Communication preferences</li>
                <li>Any other information you choose to provide</li>
              </ul>

              <h3 className="text-xl font-medium text-secondary-900 mb-2">2.2 Automatically Collected Information</h3>
              <ul className="list-disc pl-6">
                <li>Device information</li>
                <li>IP address</li>
                <li>Browser type</li>
                <li>Usage data</li>
                <li>Cookies and similar technologies</li>
              </ul>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">3. How We Use Your Information</h2>
              <p className="mb-4">We use the collected information for various purposes, including:</p>
              <ul className="list-disc pl-6">
                <li>Providing and maintaining our services</li>
                <li>Personalizing your experience</li>
                <li>Improving our AI algorithms and services</li>
                <li>Communicating with you</li>
                <li>Analyzing usage patterns</li>
                <li>Ensuring security and preventing fraud</li>
              </ul>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">4. Cookies and Tracking Technologies</h2>
              <p className="mb-4">
                We use cookies and similar tracking technologies to track activity on our platform and hold certain information. Cookies are files with a small amount of data that may include an anonymous unique identifier.
              </p>
              <p>
                You can instruct your browser to refuse all cookies or to indicate when a cookie is being sent. However, if you do not accept cookies, you may not be able to use some portions of our platform.
              </p>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">5. Data Security</h2>
              <p>
                We implement appropriate technical and organizational security measures to protect your personal information. However, please note that no method of transmission over the Internet or electronic storage is 100% secure.
              </p>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">6. Third-Party Services</h2>
              <p>
                Our platform may contain links to third-party websites or services. We are not responsible for the privacy practices or content of these third-party sites. We encourage you to review the privacy policies of any third-party sites you visit.
              </p>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">7. Your Rights</h2>
              <p className="mb-4">You have the right to:</p>
              <ul className="list-disc pl-6 mb-4">
                <li>Access your personal information</li>
                <li>Correct inaccurate data</li>
                <li>Request deletion of your data</li>
                <li>Object to processing of your data</li>
                <li>Request data portability</li>
                <li>Withdraw consent at any time</li>
                <li>Lodge a complaint with a supervisory authority</li>
                <li>Opt-out of marketing communications</li>
              </ul>
              <p>To exercise any of these rights, please contact us using the information provided in the Contact section.</p>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">13. Children's Privacy</h2>
              <p>
                Our platform is not intended for use by children under the age of 13. We do not knowingly collect personal information from children under 13. If you become aware that a child has provided us with personal information, please contact us.
              </p>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">9. Changes to This Privacy Policy</h2>
              <p>
                We may update our Privacy Policy from time to time. We will notify you of any changes by posting the new Privacy Policy on this page and updating the "Last updated" date at the top of this policy.
              </p>
            </section>

            <section>
              <h2 className="text-2xl font-semibold text-secondary-900 mb-4">10. Contact Us</h2>
              <p>
                If you have any questions about this Privacy Policy, please contact us at:
              </p>
              <div className="mt-4 p-4 bg-primary-50 rounded-xl border border-primary-100">
                <p className="font-medium text-primary-900">Sales Assist AI</p>
                <p className="text-primary-700">Email: privacy@salesassistai.com</p>
              </div>
            </section>
          </div>
        </div>
      </div>
      <Footer />
    </div>
  );
};

export default PrivacyPolicy;